# -*- coding: utf-8 -*-
# Copyright (C) 2016 Avencall
# SPDX-License-Identifier: GPL-3.0+

from xivo_confd import bus, sysconfd
from xivo_bus.resources.incall_extension.event import (IncallExtensionAssociatedEvent,
                                                       IncallExtensionDissociatedEvent)


class IncallExtensionNotifier(object):

    def __init__(self, bus, sysconfd):
        self.bus = bus
        self.sysconfd = sysconfd

    def send_sysconfd_handlers(self):
        handlers = {'ctibus': [],
                    'ipbx': ['dialplan reload'],
                    'agentbus': []}
        self.sysconfd.exec_request_handlers(handlers)

    def associated(self, incall, extension):
        self.send_sysconfd_handlers()
        event = IncallExtensionAssociatedEvent(incall.id, extension.id)
        self.bus.send_bus_event(event, event.routing_key)

    def dissociated(self, incall, extension):
        self.send_sysconfd_handlers()
        event = IncallExtensionDissociatedEvent(incall.id, extension.id)
        self.bus.send_bus_event(event, event.routing_key)


def build_notifier():
    return IncallExtensionNotifier(bus, sysconfd)
