# -*- coding: UTF-8 -*-
# Copyright 2015-2017 The Wazo Authors  (see the AUTHORS file)
# SPDX-License-Identifier: GPL-3.0+

from xivo_dao.helpers import errors
from xivo_dao.resources.user_line import dao as user_line_dao
from xivo_confd.plugins.user_line import notifier
from xivo_confd.plugins.user_line.validator import build_validator


class UserLineService(object):

    def __init__(self, dao, validator, notifier):
        self.dao = dao
        self.validator = validator
        self.notifier = notifier

    def find_all_by(self, **criteria):
        return self.dao.find_all_by(**criteria)

    def find_by(self, **criteria):
        return self.dao.find_by(**criteria)

    def get(self, user, line):
        return self.dao.get_by(user_id=user.id, line_id=line.id)

    def associate(self, user, line):
        self.validator.validate_association(user, line)
        user_line = self.dao.associate(user, line)
        self.notifier.associated(user_line)
        return user_line

    def dissociate(self, user, line):
        self.validator.validate_dissociation(user, line)
        user_line = self.dao.get_by(user_id=user.id, line_id=line.id)
        self.notifier.dissociated(user_line)
        self.dao.dissociate(user, line)

    def associate_all_lines(self, user, lines):
        if len(lines) != len(set(lines)):
            raise errors.not_permitted('Cannot associate same line more than once')

        for existing_line in user.lines:
            if existing_line not in lines:
                self.validator.validate_dissociation(user, existing_line)

        for line in lines:
            if line not in user.lines:
                self.validator.validate_association(user, line)

        for existing_line in user.lines:
            if existing_line not in lines:
                user_line = self.find_by(user_id=user.id, line_id=existing_line.id)
                self.notifier.dissociated(user_line)

        user_lines = self.dao.associate_all_lines(user, lines)

        for user_line in user_lines:
            self.notifier.associated(user_line)


def build_service():
    validator = build_validator()
    return UserLineService(user_line_dao,
                           validator,
                           notifier)
